@@ -55,13 +55,11 @@ class Task(dictobj):
             if stack:
                 stack = stacks[stack]
 
-        if stack:
-            stack.find_missing_env()
-
         credentials = None
         if task_func.needs_credentials:
-            credentials = Credentials()
-            credentials.verify_creds(configuration["environments"][environment].account_id)
+            credentials = Credentials(configuration["bespin"].region, configuration["environments"][environment].account_id,
+                                      configuration["bespin"].assume_role)
+            configuration["bespin"].credentials = credentials
 
         return task_func(overview, configuration, stacks=stacks, stack=stack, credentials=credentials)
 
